pub struct AddOnAttachmentStudentSubmission {
pub points_earned: Option<f64>,
pub post_submission_state: Option<String>,
}Expand description
Payload for grade update requests.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- course work add on attachments student submissions get courses (response)
- course work add on attachments student submissions patch courses (request|response)
- posts add on attachments student submissions get courses (response)
- posts add on attachments student submissions patch courses (request|response)
Fields
points_earned: Option<f64>Student grade on this attachment. If unset, no grade was set.
post_submission_state: Option<String>Submission state of add-on attachment’s parent post (i.e. assignment).