pub struct ListAddOnAttachmentsResponse {
pub add_on_attachments: Option<Vec<AddOnAttachment>>,
pub next_page_token: Option<String>,
}Expand description
Response when listing add-on attachments.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- announcements add on attachments list courses (response)
- course work add on attachments list courses (response)
- course work materials add on attachments list courses (response)
- posts add on attachments list courses (response)
Fields
add_on_attachments: Option<Vec<AddOnAttachment>>Attachments under the given post.
next_page_token: Option<String>A token, which can be sent as pageToken to retrieve the next page. If this field is omitted, there are no subsequent pages.