pub struct ListGuardianInvitationsResponse {
pub guardian_invitations: Option<Vec<GuardianInvitation>>,
pub next_page_token: Option<String>,
}Expand description
Response when listing guardian invitations.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- guardian invitations list user profiles (response)
Fields
guardian_invitations: Option<Vec<GuardianInvitation>>Guardian invitations that matched the list request.
next_page_token: Option<String>Token identifying the next page of results to return. If empty, no further results are available.