pub struct StudentContext {
pub submission_id: Option<String>,
}Expand description
Role-specific context if the requesting user is a student.
This type is not used in any activity, and only used as part of another schema.
Fields
submission_id: Option<String>Requesting user’s submission id to be used for grade passback and to identify the student when showing student work to the teacher. This is set exactly when supportsStudentWork is true.