Struct google_classroom1::Assignment [−][src]
pub struct Assignment {
pub student_work_folder: Option<DriveFolder>,
}Additional details for assignments.
This type is not used in any activity, and only used as part of another schema.
Fields
student_work_folder: Option<DriveFolder>
Drive folder where attachments from student submissions are placed. This is only populated for course teachers and administrators.