pub struct CourseStudentCreateCall<'a, C, A>where
C: 'a,
A: 'a,{ /* private fields */ }Expand description
Adds a user as a student of a course.
This method returns the following error codes:
PERMISSION_DENIEDif the requesting user is not permitted to create students in this course or for access errors.NOT_FOUNDif the requested course ID does not exist.FAILED_PRECONDITIONif the requested user’s account is disabled, for the following request errors:- CourseMemberLimitReached
- CourseNotModifiable
- UserGroupsMembershipLimitReached
ALREADY_EXISTSif the user is already a student or teacher in the course.
A builder for the students.create method supported by a course resource.
It is not used directly, but through a CourseMethods instance.
Example
Instantiate a resource method builder
use classroom1::Student;
// As the method needs a request, you would usually fill it with the desired information
// into the respective structure. Some of the parts shown here might not be applicable !
// Values shown here are possibly random and not representative !
let mut req = Student::default();
// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.courses().students_create(req, "courseId")
.enrollment_code("sit")
.doit();Implementations
sourceimpl<'a, C, A> CourseStudentCreateCall<'a, C, A>
impl<'a, C, A> CourseStudentCreateCall<'a, C, A>
sourcepub fn request(self, new_value: Student) -> CourseStudentCreateCall<'a, C, A>
pub fn request(self, new_value: Student) -> CourseStudentCreateCall<'a, C, A>
Sets the request property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
sourcepub fn course_id(self, new_value: &str) -> CourseStudentCreateCall<'a, C, A>
pub fn course_id(self, new_value: &str) -> CourseStudentCreateCall<'a, C, A>
Identifier of the course to create the student in. This identifier can be either the Classroom-assigned identifier or an alias.
Sets the course id path property to the given value.
Even though the property as already been set when instantiating this call, we provide this method for API completeness.
sourcepub fn enrollment_code(
self,
new_value: &str,
) -> CourseStudentCreateCall<'a, C, A>
pub fn enrollment_code( self, new_value: &str, ) -> CourseStudentCreateCall<'a, C, A>
Enrollment code of the course to create the student in. This code is required if userId corresponds to the requesting user; it may be omitted if the requesting user has administrative permissions to create students for any user.
Sets the enrollment code query property to the given value.
sourcepub fn delegate(
self,
new_value: &'a mut dyn Delegate,
) -> CourseStudentCreateCall<'a, C, A>
pub fn delegate( self, new_value: &'a mut dyn Delegate, ) -> CourseStudentCreateCall<'a, C, A>
The delegate implementation is consulted whenever there is an intermediate result, or if something goes wrong while executing the actual API request.
It should be used to handle progress information, and to implement a certain level of resilience.
Sets the delegate property to the given value.
sourcepub fn param<T>(self, name: T, value: T) -> CourseStudentCreateCall<'a, C, A>
pub fn param<T>(self, name: T, value: T) -> CourseStudentCreateCall<'a, C, A>
Set any additional parameter of the query string used in the request. It should be used to set parameters which are not yet available through their own setters.
Please note that this method must not be used to set any of the known paramters which have their own setter method. If done anyway, the request will fail.
Additional Parameters
- upload_protocol (query-string) - Upload protocol for media (e.g. “raw”, “multipart”).
- pp (query-boolean) - Pretty-print response.
- prettyPrint (query-boolean) - Returns response with indentations and line breaks.
- bearer_token (query-string) - OAuth bearer token.
- access_token (query-string) - OAuth access token.
- uploadType (query-string) - Legacy upload protocol for media (e.g. “media”, “multipart”).
- quotaUser (query-string) - Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- callback (query-string) - JSONP
- oauth_token (query-string) - OAuth 2.0 token for the current user.
- key (query-string) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- fields (query-string) - Selector specifying which fields to include in a partial response.
- alt (query-string) - Data format for response.
- $.xgafv (query-string) - V1 error format.
sourcepub fn add_scope<T>(self, scope: T) -> CourseStudentCreateCall<'a, C, A>
pub fn add_scope<T>(self, scope: T) -> CourseStudentCreateCall<'a, C, A>
Identifies the authorization scope for the method you are building.
Use this method to actively specify which scope should be used, instead the default Scope variant
Scope::ProfileEmail.
The scope will be added to a set of scopes. This is important as one can maintain access
tokens for more than one scope.
Usually there is more than one suitable scope to authorize an operation, some of which may encompass more rights than others. For example, for listing resources, a read-only scope will be sufficient, a read-write scope will do as well.