Struct google_classroom1::DriveFolder [−][src]
pub struct DriveFolder {
pub title: Option<String>,
pub id: Option<String>,
pub alternate_link: Option<String>,
}Representation of a Google Drive folder.
This type is not used in any activity, and only used as part of another schema.
Fields
title: Option<String>
Title of the Drive folder.
Read-only.
id: Option<String>
Drive API resource ID.
alternate_link: Option<String>
URL that can be used to access the Drive folder.
Read-only.