pub struct ListCourseWorkResponse {
pub next_page_token: Option<String>,
pub course_work: Option<Vec<CourseWork>>,
}Expand description
Response when listing course work.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- course work list courses (response)
Fields
next_page_token: Option<String>Token identifying the next page of results to return. If empty, no further results are available.
course_work: Option<Vec<CourseWork>>Course work items that match the request.