Struct google_classroom1::ModifyAttachmentsRequest [−][src]
pub struct ModifyAttachmentsRequest {
pub add_attachments: Option<Vec<Attachment>>,
}Request to modify the attachments of a student submission.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
add_attachments: Option<Vec<Attachment>>
Attachments to add. A student submission may not have more than 20 attachments.
Form attachments are not supported.