Struct google_classroom1::ModifyCourseWorkAssigneesRequest [−][src]
pub struct ModifyCourseWorkAssigneesRequest {
pub modify_individual_students_options: Option<ModifyIndividualStudentsOptions>,
pub assignee_mode: Option<String>,
}Request to modify assignee mode and options of a coursework.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- course work modify assignees courses (request)
Fields
modify_individual_students_options: Option<ModifyIndividualStudentsOptions>
Set which students are assigned or not assigned to the coursework.
Must be specified only when assigneeMode is INDIVIDUAL_STUDENTS.
assignee_mode: Option<String>
Mode of the coursework describing whether it will be assigned to all students or specified individual students.