Struct google_classroom1::ModifyIndividualStudentsOptions[][src]

pub struct ModifyIndividualStudentsOptions {
    pub add_student_ids: Option<Vec<String>>,
    pub remove_student_ids: Option<Vec<String>>,
}

Contains fields to add or remove students from a course work or announcement where the assigneeMode is set to INDIVIDUAL_STUDENTS.

This type is not used in any activity, and only used as part of another schema.

Fields

Ids of students to be added as having access to this coursework/announcement.

Ids of students to be removed from having access to this coursework/announcement.