[−][src]Struct google_classroom1::TurnInStudentSubmissionRequest
Request to turn in a student submission.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).